==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Gnss_/Monitor_/Display_/Antenna.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Antenna:
	"""Antenna commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("antenna", core, parent)

	def set(self, antenna: enums.RefAntenna, channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:GNSS:MONitor<CH>:DISPlay:ANTenna \n
		Sets the antenna for that the information displayed in the 'Simulation Monitor' applies. \n
			:param antenna: A1| A2| A3| A4
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Monitor')"""
		param = Conversions.enum_scalar_to_str(antenna, enums.RefAntenna)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:MONitor{channel_cmd_val}:DISPlay:ANTenna {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.RefAntenna:
		"""[SOURce<HW>]:BB:GNSS:MONitor<CH>:DISPlay:ANTenna \n
		Sets the antenna for that the information displayed in the 'Simulation Monitor' applies. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Monitor')
			:return: antenna: A1| A2| A3| A4"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:MONitor{channel_cmd_val}:DISPlay:ANTenna?')
		return Conversions.str_to_scalar_enum(response, enums.RefAntenna)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Gnss_/Monitor_/Display_/Antenna.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Antenna:
	"""Antenna commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("antenna", core, parent)

	def set(self, antenna: enums.RefAntenna, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:MONitor<CH>:DISPlay:ANTenna \n
		Snippet: driver.source.bb.gnss.monitor.display.antenna.set(antenna = enums.RefAntenna.A1, channel = repcap.Channel.Default) \n
		Sets the antenna for that the information displayed in the 'Simulation Monitor' applies. \n
			:param antenna: A1| A2| A3| A4
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Monitor')"""
		param = Conversions.enum_scalar_to_str(antenna, enums.RefAntenna)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:MONitor{channel_cmd_val}:DISPlay:ANTenna {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.RefAntenna:
		"""SCPI: [SOURce<HW>]:BB:GNSS:MONitor<CH>:DISPlay:ANTenna \n
		Snippet: value: enums.RefAntenna = driver.source.bb.gnss.monitor.display.antenna.get(channel = repcap.Channel.Default) \n
		Sets the antenna for that the information displayed in the 'Simulation Monitor' applies. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Monitor')
			:return: antenna: A1| A2| A3| A4"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:MONitor{channel_cmd_val}:DISPlay:ANTenna?')
		return Conversions.str_to_scalar_enum(response, enums.RefAntenna)
